@@ -1,6 +1,6 @@
 from typing import Optional
 
-from fa_common import sizeof_fmt, CamelModel
+from fa_common import CamelModel, sizeof_fmt
 
 
 # Shared properties
